from distutils.core import setup

setup(
    name = 'lib-auth-py',
    packages = ['lib_auth_py'],
    version = '0.1.1',  # Ideally should be same as your GitHub release tag varsion
    description = 'Update folder',
    author = 'Natarajan Kumar',
    author_email = 'natarajan@albertinvent.com',
    url = 'https://github.com/natarajanmolecule/lib-auth-py.git',
    download_url = 'https://github.com/natarajanmolecule/lib-auth-py/archive/refs/tags/0.1.1.tar.gz',
    keywords = ['jwt', 'auth'],
    classifiers = [],
)
